Struct
QmiMessageUimWriteRecordInput
since: 1.6
Description [src]
struct QmiMessageUimWriteRecordInput {
/* No available fields */
}
The QmiMessageUimWriteRecordInput structure contains private data and should only be accessed
using the provided API.
Available since: 1.6
Instance methods
qmi_message_uim_write_record_input_get_response_in_indication_token
Get the ‘Response In Indication Token’ field from self.
since: 1.37
qmi_message_uim_write_record_input_get_write_record
Get the ‘Write Record’ field from self.
since: 1.37
qmi_message_uim_write_record_input_ref
Atomically increments the reference count of self by one.
since: 1.6
qmi_message_uim_write_record_input_set_response_in_indication_token
Set the ‘Response In Indication Token’ field in the message.
since: 1.37
qmi_message_uim_write_record_input_set_write_record
Set the ‘Write Record’ field in the message.
since: 1.37
qmi_message_uim_write_record_input_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.6